==> zim-fuzzysearch-0.8.1.tgz: package/lib/components/index.js <==
import React from "react";
import { useFuse } from "./hooks/useFuse";
import { FuzzyInputProvider } from "./hooks/useFuzzyInput";
import { FuzzyResultProvider } from "./hooks/useFuzzyResult";
import FuzzyGui from "./FuzzyGui";
// fuse specific default option
var optionsDefault = {
    //includeMatches: true,
    ignoreLocation: true,
    ignoreFieldNorm: false,
    includeScore: true,
    keys: ["label", "txt", "tags"]
};
//default options for mark.js
var markOptionsDefault = {
    element: "b",
    accuracy: "complementary",
    exclude: ["h5"],
};
var ZIMFuzzySearch = function (_a) {
    var data = _a.data, tagConceptMap = _a.tagConceptMap, onSelect = _a.onSelect, onSearch = _a.onSearch, onFuseKeySelect = _a.onFuseKeySelect, searchInput = _a.searchInput, _b = _a.placeHolder, placeHolder = _b === void 0 ? "Search..." : _b, onInput = _a.onInput, _c = _a.fuseOptions, fuseOptions = _c === void 0 ? optionsDefault : _c, _d = _a.markOptions, markOptions = _d === void 0 ? markOptionsDefault : _d, _e = _a.resultCountLabel, resultCountLabel = _e === void 0 ? "Matches: " : _e, _f = _a.searchOnClick, searchOnClick = _f === void 0 ? false : _f, _g = _a.showResultGrid, showResultGrid = _g === void 0 ? false : _g, _h = _a.fuseKeyMap, fuseKeyMap = _h === void 0 ? null : _h, _j = _a.fuseKeyAllLabel, fuseKeyAllLabel = _j === void 0 ? "All" : _j, children = _a.children;
    var _k = React.useState(fuseOptions), fuseStateOptions = _k[0], setFuseStateOptions = _k[1];
    var _l = React.useState(searchInput ? searchInput : null), inputVal = _l[0], setInputVal = _l[1];
    var fuseSearchInputDelay = React.useRef(undefined);
    var _m = useFuse(fuseStateOptions, data), fuseResult = _m.fuseResult, doFuseSearch = _m.doFuseSearch, groupBy = _m.groupBy, resetFuse = _m.resetFuse;
    // two way binding
    React.useEffect(function () {
        if (!searchInput)
            return;
        setInputVal(searchInput);
    }, [searchInput, data]);
    // when value set from outside -> do a fuse serach once
    React.useEffect(function () {
        if (!searchInput)
            return;
        // when value set from outside -> trigger search once.
        if (searchOnClick && !fuseResult && data) {
            doFuseSearch(searchInput);
            if (onSearch)
                onSearch(searchInput);
        }
    }, [data]);
    // when input change do search when not in clickmode.
    // timer delays init auf fusesearch(e.g. if multiple inputs)
    React.useEffect(function () {
        if (fuseSearchInputDelay.current)
            clearTimeout(fuseSearchInputDelay.current);
        if (!searchOnClick && inputVal) {
            fuseSearchInputDelay.current = setTimeout(function () {
                if (fuseSearchInputDelay.current) {
                    doFuseSearch(inputVal);
                    if (onSearch)
                        onSearch(inputVal);
                }
            }, 300);
        }
        else if (inputVal === null) {
            resetFuse();
        }
    }, [searchInput, data, inputVal]);
    var handleInput = function (val) {
        setInputVal(val);
        // ensure two way binding
        if (onInput)
            onInput(val ? val : "");
    };
    var toggleFuseKey = function (fuseKeys) {
        var copy = JSON.parse(JSON.stringify(fuseSearchInputDelay));
        copy.keys = fuseKeys;
        setFuseStateOptions(copy);
        if (onFuseKeySelect)
            onFuseKeySelect(fuseKeys);
    };
    /**
     * Trigger fuse search whenever fuse options change.
     */
    React.useEffect(function () {
        //do only fire 
        if (fuseOptions === fuseStateOptions)
            return;
        if (!inputVal)
            return;
        doFuseSearch(inputVal);
    }, [fuseStateOptions]);
    return (React.createElement(FuzzyInputProvider, { fuseStateOptions: fuseStateOptions, fuseKeyMap: fuseKeyMap, fuseKeyAllLabel: fuseKeyAllLabel, toggleFuseKey: toggleFuseKey, clickMode: searchOnClick, doSearch: doFuseSearch, onSearch: onSearch, handleInput: handleInput, inputVal: inputVal, placeHolder: placeHolder, data: data },
        React.createElement(FuzzyResultProvider, { fuzzyResult: fuseResult, onSelect: onSelect, resultCountLabel: resultCountLabel, showResultGrid: showResultGrid, tagConceptMap: tagConceptMap }, children ? children : React.createElement(FuzzyGui, { markOptions: markOptions }))));
};
export default ZIMFuzzySearch;

==> zim-fuzzysearch-0.8.2.tgz: package/lib/components/index.js <==
import React from "react";
import { useFuse } from "./hooks/useFuse";
import { FuzzyInputProvider } from "./hooks/useFuzzyInput";
import { FuzzyResultProvider } from "./hooks/useFuzzyResult";
import FuzzyGui from "./FuzzyGui";
// fuse specific default option
var optionsDefault = {
    //includeMatches: true,
    ignoreLocation: true,
    ignoreFieldNorm: false,
    includeScore: true,
    keys: ["label", "txt", "tags"]
};
//default options for mark.js
var markOptionsDefault = {
    element: "b",
    accuracy: "complementary",
    exclude: ["h5"],
};
var ZIMFuzzySearch = function (_a) {
    var data = _a.data, tagConceptMap = _a.tagConceptMap, onSelect = _a.onSelect, onSearch = _a.onSearch, onFuseKeySelect = _a.onFuseKeySelect, searchInput = _a.searchInput, _b = _a.placeHolder, placeHolder = _b === void 0 ? "Search..." : _b, onInput = _a.onInput, _c = _a.fuseOptions, fuseOptions = _c === void 0 ? optionsDefault : _c, _d = _a.markOptions, markOptions = _d === void 0 ? markOptionsDefault : _d, _e = _a.resultCountLabel, resultCountLabel = _e === void 0 ? "Matches: " : _e, _f = _a.searchOnClick, searchOnClick = _f === void 0 ? false : _f, _g = _a.showResultGrid, showResultGrid = _g === void 0 ? false : _g, _h = _a.fuseKeyMap, fuseKeyMap = _h === void 0 ? null : _h, _j = _a.fuseKeyAllLabel, fuseKeyAllLabel = _j === void 0 ? "All" : _j, children = _a.children;
    var _k = React.useState(fuseOptions), fuseStateOptions = _k[0], setFuseStateOptions = _k[1];
    var _l = React.useState(searchInput ? searchInput : null), inputVal = _l[0], setInputVal = _l[1];
    var fuseSearchInputDelay = React.useRef(undefined);
    var _m = useFuse(fuseStateOptions, data), fuseResult = _m.fuseResult, doFuseSearch = _m.doFuseSearch, groupBy = _m.groupBy, resetFuse = _m.resetFuse;
    // two way binding
    React.useEffect(function () {
        if (!searchInput)
            return;
        setInputVal(searchInput);
    }, [searchInput, data]);
    // when value set from outside -> do a fuse serach once
    React.useEffect(function () {
        if (!searchInput)
            return;
        // when value set from outside -> trigger search once.
        if (searchOnClick && !fuseResult && data) {
            doFuseSearch(searchInput);
            if (onSearch)
                onSearch(searchInput);
        }
    }, [data]);
    // when input change do search when not in clickmode.
    // timer delays init auf fusesearch(e.g. if multiple inputs)
    React.useEffect(function () {
        if (fuseSearchInputDelay.current)
            clearTimeout(fuseSearchInputDelay.current);
        if (!searchOnClick && inputVal) {
            fuseSearchInputDelay.current = setTimeout(function () {
                if (fuseSearchInputDelay.current) {
                    doFuseSearch(inputVal);
                    if (onSearch)
                        onSearch(inputVal);
                }
            }, 300);
        }
        else if (inputVal === null) {
            resetFuse();
        }
    }, [searchInput, data, inputVal]);
    var handleInput = function (val) {
        setInputVal(val);
        // ensure two way binding
        if (onInput)
            onInput(val ? val : "");
    };
    var toggleFuseKey = function (fuseKeys) {
        var copy = JSON.parse(JSON.stringify(fuseStateOptions));
        copy.keys = fuseKeys;
        setFuseStateOptions(copy);
        if (onFuseKeySelect)
            onFuseKeySelect(fuseKeys);
    };
    /**
     * Trigger fuse search whenever fuse options change.
     */
    React.useEffect(function () {
        //do only fire 
        if (fuseOptions === fuseStateOptions)
            return;
        if (!inputVal)
            return;
        doFuseSearch(inputVal);
    }, [fuseStateOptions]);
    return (React.createElement(FuzzyInputProvider, { fuseStateOptions: fuseStateOptions, fuseKeyMap: fuseKeyMap, fuseKeyAllLabel: fuseKeyAllLabel, toggleFuseKey: toggleFuseKey, clickMode: searchOnClick, doSearch: doFuseSearch, onSearch: onSearch, handleInput: handleInput, inputVal: inputVal, placeHolder: placeHolder, data: data },
        React.createElement(FuzzyResultProvider, { fuzzyResult: fuseResult, onSelect: onSelect, resultCountLabel: resultCountLabel, showResultGrid: showResultGrid, tagConceptMap: tagConceptMap }, children ? children : React.createElement(FuzzyGui, { markOptions: markOptions }))));
};
export default ZIMFuzzySearch;
